export default {
  meta: {
    type: 'problem',
    docs: {
      description: 'Enforce <script> to have the \'setup\' attribute',
      category: 'Best Practices',
      recommended: false,
    },
    fixable: 'code',
    schema: [],
  },
  create(context) {
    return {
      Program(_node) {
        const sourceCode = context.getSourceCode()
        const tokens = sourceCode.ast.tokens
        const code = sourceCode.getText()
        const file_name = context.getFilename()
        if (!file_name.endsWith('.vue')) {
          return
        }
        if (file_name.includes('node_modules')) {
          return
        }

        tokens.forEach((token) => {
          if (token.type === 'Punctuator' && token.value === '<script>') {
            const script_tag = code.slice(token.range[0], token.range[1])
            if (!/\bsetup\b/.test(script_tag)) {
              context.report({
                node: token,
                message: '<script> tags must have the \'setup\' attribute.',
                fix(fixer) {
                  return fixer.replaceTextRange([token.range[0], token.range[0] + '<script'.length], '<script setup')
                },
              })
            }
          }
        })
      },
    }
  },
}
